/* Copyright (C) 2022 Facility for Antiproton and Ion Research in Europe, Darmstadt
   SPDX-License-Identifier: GPL-3.0-only
   Authors: Dominik Smith [committer], Pierre-Alain Loizeau, Felix Weiglhofer */
#pragma once

#include <vector>

#include "Math/Rotation3D.h"
#include "Math/Vector3Dfwd.h"


namespace cbm::algo::tof
{
  struct TofCell {
    double sizeX, sizeY;
    ROOT::Math::XYZVector pos;
    ROOT::Math::Rotation3D rotation;
  };

  struct ClusterizerChanPar {
    std::vector<double> fvCPTOff;               //[nbSide]
    std::vector<double> fvCPTotGain;            //[nbSide]
    std::vector<double> fvCPTotOff;             //[nbSide]
    std::vector<std::vector<double>> fvCPWalk;  //[nbSide][nbWalkBins]
    int32_t address;                            //unique address
    TofCell cell;
  };

  struct ClusterizerRpcPar {
    uint32_t fDeadStrips;
    double fPosYMaxScal;
    double fdMaxTimeDist;
    double fdMaxSpaceDist;
    double fSigVel;
    double fTimeRes;
    int32_t numClWalkBinX;
    double TOTMax;
    double TOTMin;
    bool swapChannelSides;
    double channelDeadtime;
    double fCPTOffYBinWidth;
    double fCPTOffYRange;
    std::vector<double> fCPTOffY;  //[nBin]
    std::vector<ClusterizerChanPar> fChanPar = {};
  };

}  // namespace cbm::algo::tof
