/* Copyright (C) 2023 FIAS Frankfurt Institute for Advanced Studies, Frankfurt / Main
   SPDX-License-Identifier: GPL-3.0-only
   Authors: Felix Weiglhofer [committer] */
#include "HitfinderChain.h"

#include "config/Yaml.h"

using namespace cbm::algo;
using namespace cbm::algo::tof;

void HitfinderChain::Init()
{
  auto setup           = config::ReadFromFile<HitfindSetup>(Opts().ParamsDir() / "TofHitfinderPar.yaml");
  fHitfind             = std::make_unique<Hitfind>();
  fHitfind->fTofConfig = setup;
  fHitfind->Init();
}

HitfinderChain::ReturnType HitfinderChain::Run(gsl::span<CbmTofDigi> digis)
{
  auto ret = (*fHitfind)(digis);

  L_(info) << "TS contains " << ret.first.NElements() << " TOF Hits";
  L_(error) << "TOF Digis with unknown RPCs: " << ret.second.fDigiCalibUnknownRPC;
  return ret;
}
